@@ -45,8 +45,6 @@
  * file. It is the central component of the controller part.
  *
  */
-
-
 $SPAF_VERSION = '2.2.0';
 header('Content-Type: text/html; charset=utf-8');
 
@@ -67,7 +65,7 @@ if (file_exists($MODULE.'/pre_init.php')) {
 
 require 'SPAF2/Application.php';
 
-if (! isset($configfile)) {
+if ((! isset($SP_CONFIG)) && (! isset($configfile))) {
     echo "Main configfile not set!";
     exit();
 }
@@ -196,7 +194,7 @@ if (file_exists($MODULE.'/post_ctrl.php')) {
  * controller will not checked for authorization.
  *
  */
-$App->log("VIEW[$ACCESS_LEVEL] ".$App->view,2,'SPAF2');
+$App->log("VIEW[$ACCESS_LEVEL]) ".$App->view,2,'SPAF2');
 // check if file exists or call default view file. The default view
 // will not checked for authorization.
 $SP_FILE = $MODULE.'/view/' . $App->view . '.php';
@@ -240,7 +238,7 @@ $App->assign('VIEW',$App->view);
 if ($App->getParam('SKIN')) {
     $App->setSkin($App->getParam('SKIN'));
 }
-
+@
 $App->log("TPL[$ACCESS_LEVEL] $App->view",2,'SPAF2');
 $App->template = $App->view;
 // header and footer relative to template_root
