@@ -300,6 +300,11 @@ class Application extends ApplicationConfig
         $this->tpl_root = getcwd().'/'.$this->getConfig('TEMPLATE_ROOT','../')
                           .'/templates';
         $this->TPL = new Smarty;
+        $this->TPL->error_reporting = false;
+        if ($this->DEBUG < 5) {
+            error_reporting(E_ALL ^ E_WARNING ^ E_NOTICE);
+        }
+
         $this->TPL->compile_check = true;
 
         if (isset($this->config['DBTYPE'])) {
@@ -473,7 +478,6 @@ class Application extends ApplicationConfig
          * method.
          */
         ob_start();
-        //if (file_exists(SMARTY_DIR.'/'.$template)) {
         if (file_exists($template)) {
             $this->TPL->display($template);
             $this->_output .= ob_get_contents();
@@ -712,6 +716,8 @@ class Application extends ApplicationConfig
    function redirect ($action,$plist=array())
     {
 
+        $params = '';
+
         // redirect to another script if "?" given
         @list($script,$ca) = explode('?',$action);
         if ($ca) {
