@@ -85,7 +85,12 @@ class ApplicationConfig
      */
     function load ($file,$die_on_error=true)
     {
-        $cfile = $this->configdir .'/'. $file;
+        if (substr($file, 0, 1) == '/') {
+            $cfile = $file;
+        }
+        else {
+            $cfile = $this->configdir .'/'. $file;
+        }
 
         if (! $fd = @fopen ($cfile, "r")) {
             $dir = $_SERVER['SCRIPT_FILENAME'];
