@@ -31,6 +31,11 @@
  * Suite 330, Boston, MA  02111-1307  USA
  */
 
+// check cookie settings
+if (ini_get('session.cookie_secure')) {
+    @$_SERVER['HTTPS'] || error_log('BENNO RUNTIME ERROR: plaintext request while secure cookies enabled');
+}
+
 // set cookie path
 $currentCookieParams = session_get_cookie_params();
 	session_set_cookie_params(
