@@ -52,9 +52,9 @@ class Benno
      */
     function __construct()
     {
-        $this->infoText = 'Benno MailArchiv Version 2.8.20'; 
-        $this->buildInfo= '221222191416/97576fa';
-        $this->buildYear= '2022';
+        $this->infoText = 'Benno MailArchiv Version 2.8.21-1'; 
+        $this->buildInfo= '230306163716/8ad051e';
+        $this->buildYear= '2023';
     }
 
 }
